intelmq.bots.experts.abusix package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.abusix package

## Submodules

## intelmq.bots.experts.abusix.expert module

Reference: https://abusix.com/contactdb.html RIPE abuse contacts resolving through DNS TXT queries

class intelmq.bots.experts.abusix.expert.AbusixExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Add abuse contact information from the Abusix online service for source and destination IP address

  init()
  process()

intelmq.bots.experts.abusix.expert.BOT

  alias of `intelmq.bots.experts.abusix.expert.AbusixExpertBot`

## intelmq.bots.experts.abusix.lib module

## Module contents